<?php

/**
 * @file
 * password_reset_admin.inc contains forms and functions solely for use by those
 * with administrative permissions.
 */

/**
 * Menu callback: Display the settings form.
 */
function password_reset_settings_form() {
  $config = _password_reset_variable_get();

  $form['password_reset'] = array(
    '#tree' => TRUE
  );
  $form['password_reset']['flood_control'] = array(
    '#type' => 'select',
    '#title' => t('Hourly threshold'),
    '#options' => range(0, 10),
    '#default_value' => $config['flood_control'],
    '#description' => t('The maximum number of times a user can attempt to reset the password in an hour. Set to 0 for unlimited attempts.')
  );
  $form['password_reset']['redirect_user'] = array(
    '#type' => 'checkbox',
    '#title' => t('Redirect users upon login.'),
    '#default_value' => $config['redirect_user'],
    '#description' => t('Users who have <em>not</em> filled in their Password Reset question and answer will be directed to their user edit page upon login.')
  );

  return system_settings_form($form);
}

/**
 * Menu callback: List the security questions.
 */
function password_reset_admin_questions() {
  $result = db_query('SELECT pr.qid, pr.question, COUNT(pru.qid) as total FROM {password_reset} pr LEFT JOIN {password_reset_users} pru USING (qid) GROUP BY pr.qid ORDER BY question');

  $rows = array();
  foreach ($result as $question) {
    $rows[] = array($question->question, $question->total, l(t('Edit'), 'admin/config/people/password-reset/edit/' . $question->qid), l(t('Delete'), 'admin/config/people/password-reset/delete/' . $question->qid));
  }

  if (empty($rows)) {
    $rows[] = array(array('data' => t('No questions found.'), 'colspan' => 4));
  }

  $header = array(t('Question'), t('Use count'), array('data' => t('Operations'), 'colspan' => 2));

  return theme('table', array('header' => $header, 'rows' => $rows));
}

/**
 * Menu callback: Question edit page.
 */
function password_reset_admin_edit($form, &$form_state, $qid = NULL) {
  $form['question'] = array(
    '#type' => 'textfield',
    '#title' => t('Security question'),
    '#maxlength' => 255,
    '#description' => t("Example: 'What is your library card number?' or 'What is your mother's maiden name?'."),
    '#required' => TRUE
  );
  $form['answer_length'] = array(
    '#type' => 'textfield',
    '#title' => t('Minimum answer length'),
    '#maxlength' => 4,
    '#description' => t("The minimum length required for the answer."),
    '#default_value' => 1,
    '#required' => TRUE
  );

  $form['submit'] = array('#type' => 'submit', '#value' => t('Add question'));
  if (arg(4) == 'edit' && isset($qid)) {
    $question = password_reset_question_get($qid);
    $form['question']['#default_value'] = $question->question;
    $form['answer_length']['#default_value'] = $question->answer_length;
    $form['qid'] = array('#type' => 'value', '#value' => $qid);
    $form['submit']['#value'] = t('Update question');
  }

  return $form;
}

/**
 * Process the password_reset question edit page form submission.
 */
function password_reset_admin_edit_submit($form, &$form_state) {
  if (isset($form_state['values']['qid'])) {
    password_reset_question_add($form_state['values'], 'qid');

    // Redirect only updated question submissions back to the question list.
    $form_state['redirect'] = 'admin/config/people/password-reset';
  }
  else {
    password_reset_question_add($form_state['values']);
  }
}

/**
 * Menu callback: Question delete page.
 */
function password_reset_admin_delete($form, &$form_state, $qid) {
  if ($info = db_query("SELECT * FROM {password_reset} WHERE qid = :qid", array(':qid' => $qid))->fetchObject()) {
    $form['question'] = array('#type' => 'value', '#value' => $info->question);
    $form['qid'] = array('#type' => 'value', '#value' => $info->qid);

    return confirm_form(
      $form,
      t('Are you sure you want to delete %question?', array('%question' => $info->question)),
      'admin/config/people/password-reset',
      t('Users who have chosen this as their security question will have to update their profiles. This action cannot be undone.'),
      t('Delete'),
      t('Cancel')
    );
  }
}

/**
 * Process question delete form submission.
 */
function password_reset_admin_delete_submit($form, &$form_state) {
  password_reset_question_delete($form_state['values']);
  $form_state['redirect'] = 'admin/config/people/password-reset';
}
